==> Iacorner_0.22_dev.zip: an/db/firebird/sql/01_TABLE/AN01S.sql <==
/**************************************************************************/
/* AN01 ( アンケートマスタ )                                              */
/*                                                                        */
/* Created : 2010/09/27 16:41:35                                          */
/**************************************************************************/
CREATE TABLE AN01 (
   USERID     VARCHAR(10)                              NOT NULL                  /* 1  ユーザーID             */
 , CDANK      VARCHAR(10)                              NOT NULL                  /* 2  アンケートC            */
 , NMANK      VARCHAR(500)                             NOT NULL                  /* 3  アンケート名称         */
 , SMANK      BLOB                                                               /* 4  アンケート概要         */
 , DYKSTR     VARCHAR(14)     DEFAULT '00000101000000' NOT NULL                  /* 5  公開開始日             */
 , DYKEND     VARCHAR(14)     DEFAULT '99991231000000' NOT NULL                  /* 6  公開終了日             */
 , FGKOKAI    VARCHAR(1)      DEFAULT '0'              NOT NULL                  /* 7  公開F                  */
 , FGNODPL    VARCHAR(1)      DEFAULT '0'              NOT NULL                  /* 8  複数回答禁止F          */
 , FGTEMPLATE VARCHAR(1)      DEFAULT '0'              NOT NULL                  /* 9  雛形F                  */
 , KTSTAGS    BLOB                                                               /* 10 回答者タグ             */
 , IRAIADDRS  BLOB                                                               /* 11 回答依頼送信先         */
 , IRAIMLDT   VARCHAR(14)                                                        /* 12 回答依頼メール送信日時 */
 , BIKO       BLOB                                                               /* 13 備考                   */
 , CHECKKEY   VARCHAR(200)                                                       /* 14 チェックキー(暗号化前) */
 , CRYPTKEY   VARCHAR(200)                                                       /* 15 チェックキー(暗号化後) */
 , FGSHUBETSU VARCHAR(1)      DEFAULT '1'              NOT NULL                  /* 16 種別F                  */
 , FGRESDISP  VARCHAR(1)      DEFAULT '1'              NOT NULL                  /* 17 結果表示F              */
 , UNIQ       BIGINT                                   NOT NULL PRIMARY KEY      /* 18 ユニークキー           */
 , FGJ        VARCHAR(1)      DEFAULT '1'              NOT NULL                  /* 19 状態フラグ             */
 , DYSET      VARCHAR(14)                                                        /* 20 登録日時               */
 , PGSET      VARCHAR(10)                                                        /* 21 作成PG                 */
 , PGPSET     VARCHAR(10)                                                        /* 22 作成親PG               */
 , USRSET     VARCHAR(10)                                                        /* 23 作成社員               */
 , DYUPD      VARCHAR(14)                                                        /* 24 更新日時               */
 , PGUPD      VARCHAR(10)                                                        /* 25 更新PG                 */
 , PGPUPD     VARCHAR(10)                                                        /* 26 更新親PG               */
 , USRUPD     VARCHAR(10)                                                        /* 27 更新者                 */
);

CREATE SEQUENCE AN01S00 ;


CREATE TRIGGER AN01T00 FOR AN01
  BEFORE INSERT 
  AS BEGIN 
    NEW.UNIQ = GEN_ID( AN01S00,1 );
  END;

==> Iacorner_0.23_dev.zip: an/db/firebird/sql/01_TABLE/AN01S.sql <==
/**************************************************************************/
/* AN01 ( アンケートマスタ )                                              */
/*                                                                        */
/* Created : 2010/10/08 09:29:33                                          */
/**************************************************************************/
CREATE TABLE AN01 (
   USERID     VARCHAR(10)                              NOT NULL                  /* 1  ユーザーID             */
 , CDANK      VARCHAR(10)                              NOT NULL                  /* 2  アンケートC            */
 , NMANK      VARCHAR(500)                             NOT NULL                  /* 3  アンケート名称         */
 , SMANK      BLOB                                                               /* 4  アンケート概要         */
 , DYKSTR     VARCHAR(14)     DEFAULT '00000101000000' NOT NULL                  /* 5  公開開始日             */
 , DYKEND     VARCHAR(14)     DEFAULT '99991231000000' NOT NULL                  /* 6  公開終了日             */
 , FGKOKAI    VARCHAR(1)      DEFAULT '0'              NOT NULL                  /* 7  公開方法               */
 , FGNODPL    VARCHAR(1)      DEFAULT '0'              NOT NULL                  /* 8  複数回答禁止           */
 , FGTEMPLATE VARCHAR(1)      DEFAULT '0'              NOT NULL                  /* 9  雛形                   */
 , KTSTAGS    BLOB                                                               /* 10 回答者タグ             */
 , IRAIADDRS  BLOB                                                               /* 11 回答依頼送信先         */
 , IRAIMLDT   VARCHAR(14)                                                        /* 12 回答依頼メール送信日時 */
 , BIKO       BLOB                                                               /* 13 備考                   */
 , CHECKKEY   VARCHAR(200)                                                       /* 14 チェックキー(暗号化前) */
 , CRYPTKEY   VARCHAR(200)                                                       /* 15 チェックキー(暗号化後) */
 , FGSHUBETSU VARCHAR(1)      DEFAULT '1'              NOT NULL                  /* 16 種別                   */
 , FGRESDISP  VARCHAR(1)      DEFAULT '1'              NOT NULL                  /* 17 結果表示               */
 , UNIQ       BIGINT                                   NOT NULL PRIMARY KEY      /* 18 ユニークキー           */
 , FGJ        VARCHAR(1)      DEFAULT '1'              NOT NULL                  /* 19 状態フラグ             */
 , DYSET      VARCHAR(14)                                                        /* 20 登録日時               */
 , PGSET      VARCHAR(10)                                                        /* 21 作成PG                 */
 , PGPSET     VARCHAR(10)                                                        /* 22 作成親PG               */
 , USRSET     VARCHAR(10)                                                        /* 23 作成社員               */
 , DYUPD      VARCHAR(14)                                                        /* 24 更新日時               */
 , PGUPD      VARCHAR(10)                                                        /* 25 更新PG                 */
 , PGPUPD     VARCHAR(10)                                                        /* 26 更新親PG               */
 , USRUPD     VARCHAR(10)                                                        /* 27 更新者                 */
);

CREATE SEQUENCE AN01S00 ;


CREATE TRIGGER AN01T00 FOR AN01
  BEFORE INSERT 
  AS BEGIN 
    NEW.UNIQ = GEN_ID( AN01S00,1 );
  END;
